@@ -64,7 +64,7 @@ class PartitionSerializer(serializers.ModelSerializer):
 
 
 class MountedVolumeSerializer(serializers.ModelSerializer):
-    fs = NestedFilesystemSerializer(required=False, allow_null=True)
+    fs_type = NestedFilesystemSerializer(required=False, allow_null=True)
     device = NestedDeviceSerializer(required=False, allow_null=True)
 
     class Meta:
