@@ -5,11 +5,11 @@ from rest_framework.routers import APIRootView
 from netbox.api.viewsets import NetBoxModelViewSet
 from netbox_storage.api.serializers import (
     DriveSerializer,
-    FilesystemSerializer, PartitionSerializer, MountedVolumeSerializer
+    FilesystemSerializer, PartitionSerializer, MountedVolumeSerializer, LinuxDeviceSerializer
 )
 from netbox_storage.filters import DriveFilter, FilesystemFilter, \
-    PartitionFilter, MountedVolumeFilter
-from netbox_storage.models import Drive, Filesystem, Partition, MountedVolume
+    PartitionFilter, MountedVolumeFilter, LinuxDeviceFilter
+from netbox_storage.models import Drive, Filesystem, Partition, MountedVolume, LinuxDevice
 
 
 class NetboxStorageRootView(APIRootView):
@@ -68,3 +68,14 @@ class MountedVolumeViewSet(NetBoxModelViewSet):
         serializer = MountedVolumeSerializer(mountedvolume, many=True, context={"request": request})
         return Response(serializer.data)
 
+
+class LinuxDeviceViewSet(NetBoxModelViewSet):
+    queryset = LinuxDevice.objects.all()
+    serializer_class = LinuxDeviceSerializer
+    filterset_class = LinuxDeviceFilter
+
+    @action(detail=True, methods=["get"])
+    def linuxdevice(self, request, pk=None):
+        linuxdevice = LinuxDevice.objects.filter(linuxdevice__id=pk)
+        serializer = LinuxDeviceSerializer(linuxdevice, many=True, context={"request": request})
+        return Response(serializer.data)
