@@ -1,6 +1,6 @@
 from .drive import *
 from .filesystem import *
-from .linux_volume import *
+from .mounted_volume import *
 from .partition import *
 from .simple import *
 from .linux_device import *
