@@ -70,8 +70,8 @@ class MountedVolumeFilterForm(NetBoxModelFilterSetForm):
         },
         help_text="The Partition for the LinuxVolume e.g. /dev/sda1",
     )
-    path = CharField(
-        label="Path",
+    mount_point = CharField(
+        label="Mount Point",
         help_text="The mounted path of the volume e.g. /var/lib/docker",
     )
     fs = DynamicModelChoiceField(
@@ -108,9 +108,9 @@ class MountedVolumeImportForm(NetBoxModelImportForm):
 class MountedVolumeBulkEditForm(NetBoxModelBulkEditForm):
     model = MountedVolume
 
-    path = CharField(
+    mount_point = CharField(
         required=False,
-        label="Path",
+        label="mount_point",
     )
     fs = DynamicModelChoiceField(
         queryset=Filesystem.objects.all(),
