@@ -33,9 +33,9 @@ class LVMTemplateForm(NetBoxModelForm):
         help_text="The size of the logical volume e.g. 25",
         validators=[MinValueValidator(0.1)],
     )
-    path = CharField(
-        label="Path",
-        help_text="The mounted path of the volume e.g. /var/lib/docker",
+    mount_point = CharField(
+        label="mount_point",
+        help_text="The mounted point of the volume e.g. /var/lib/docker",
     )
     fs = DynamicModelChoiceField(
         queryset=Filesystem.objects.all(),
@@ -81,7 +81,7 @@ class LVMTemplateForm(NetBoxModelForm):
                 "lv_name",
                 "vg_name",
                 "size",
-                "path",
+                "mount_point",
                 "fs",
                 "description",
             ),
@@ -93,7 +93,7 @@ class LVMTemplateForm(NetBoxModelForm):
         exclude = (
             "cluster_type",
             "vg_name",
-            "path",
+            "mount_point",
             "fs",
             "description",
             "cluster",
@@ -114,12 +114,12 @@ class LVMTemplateForm(NetBoxModelForm):
         logicalvolume = LogicalVolume.objects.create(vg=volumegroup,
                                                      lv_name=self.cleaned_data['lv_name'],
                                                      size=self.cleaned_data['size'],
-                                                     path=self.cleaned_data['path'],
+                                                     mount_point=self.cleaned_data['mount_point'],
                                                      fs=self.cleaned_data['fs'])
         print(f"{self.cleaned_data['lv_name']}")
         print(f"{self.cleaned_data['vg_name']}")
         print(f"{self.cleaned_data['size']}")
-        print(f"{self.cleaned_data['path']}")
+        print(f"{self.cleaned_data['mount_point']}")
         print(f"{self.cleaned_data['fs']}")
 
         print("Instances")
@@ -138,9 +138,9 @@ class LinuxVolumeTemplateForm(NetBoxModelForm):
         help_text="The size of the logical volume e.g. 25",
         validators=[MinValueValidator(0.1)],
     )
-    path = CharField(
-        label="Path",
-        help_text="The mounted path of the volume e.g. /var/lib/docker",
+    mount_point = CharField(
+        label="mount_point",
+        help_text="The mounted point of the volume e.g. /var/lib/docker",
     )
     fs = DynamicModelChoiceField(
         queryset=Filesystem.objects.all(),
@@ -184,7 +184,7 @@ class LinuxVolumeTemplateForm(NetBoxModelForm):
             "Linux Volume Configuration",
             (
                 "size",
-                "path",
+                "mount_point",
                 "fs",
                 "description",
             ),
@@ -206,13 +206,13 @@ class LinuxVolumeTemplateForm(NetBoxModelForm):
         #                                      type='Linux', description='Partition 1 on SSD Cluster')
 
         linux_volume = MountedVolume.objects.create(device=linux_device, size=self.cleaned_data['size'],
-                                                    path=self.cleaned_data['path'], fs=self.cleaned_data['fs'],
+                                                    mount_point=self.cleaned_data['mount_point'], fs=self.cleaned_data['fs'],
                                                     description='Linux volume')
         self.instance.linux_volume = linux_volume
         template_configuration = super().save(*args, **kwargs)
 
         print(f"{self.cleaned_data['size']}")
-        print(f"{self.cleaned_data['path']}")
+        print(f"{self.cleaned_data['mount_point']}")
         print(f"{self.cleaned_data['fs']}")
 
         print("Instances")
@@ -292,9 +292,9 @@ class PartitionTemplateForm(NetBoxModelForm):
         queryset=Platform.objects.all(),
         help_text="Mapping between Volume and platform e.g. Rocky Linux 8",
     )
-    path = CharField(
-        label="Path",
-        help_text="The mounted path of the volume e.g. /var/lib/docker",
+    mount_point = CharField(
+        label="mount_point",
+        help_text="The mounted point of the volume e.g. /var/lib/docker",
     )
     fs_type = DynamicModelChoiceField(
         queryset=Filesystem.objects.all(),
@@ -307,12 +307,12 @@ class PartitionTemplateForm(NetBoxModelForm):
     fs_options = CharField(
         required=False,
         label="FS Options",
-        help_text="The mounted path of the volume e.g. /var/lib/docker",
+        help_text="The mounted point of the volume e.g. /var/lib/docker",
     )
     label = CharField(
         required=False,
         label="Partition Label",
-        help_text="The mounted path of the volume e.g. /var/lib/docker",
+        help_text="The mounted point of the volume e.g. /var/lib/docker",
     )
 
     fieldsets = (
@@ -326,7 +326,7 @@ class PartitionTemplateForm(NetBoxModelForm):
         (
             "Select drive",
             (
-                "path",
+                "mount_point",
                 "size",
                 "fs_type",
                 "fs_options",
@@ -354,7 +354,7 @@ class PartitionTemplateForm(NetBoxModelForm):
 
         linux_device = LinuxDevice.objects.create(device=device_name, type='efi')
 
-        MountedVolume.objects.create(device=linux_device, mount_point=self.cleaned_data['path'],
+        MountedVolume.objects.create(device=linux_device, mount_point=self.cleaned_data['mount_point'],
                                      fs_type=self.cleaned_data['fs_type'], options=self.cleaned_data['fs_options'])
 
         self.instance.drive = self.cleaned_data['drive']
@@ -385,9 +385,9 @@ class VolumeSimpleForm(NetBoxModelForm):
         help_text="The volume group name e.g. vg_data",
         required=False
     )
-    path = CharField(
-        label="Path",
-        help_text="The mounted path of the volume e.g. /var/lib/docker",
+    mount_point = CharField(
+        label="mount_point",
+        help_text="The mounted point of the volume e.g. /var/lib/docker",
         required=False
     )
     hard_drive_label = CharField(
@@ -438,7 +438,7 @@ class VolumeSimpleForm(NetBoxModelForm):
         print(f"{self.cleaned_data['lv_data']}")
         print(f"{self.cleaned_data['vg_data']}")
         print(f"{self.cleaned_data['size']}")
-        print(f"{self.cleaned_data['path']}")
+        print(f"{self.cleaned_data['mount_point']}")
         print(f"{self.cleaned_data['fs']}")
 
         return drive
