@@ -273,7 +273,7 @@ class LogicalVolume(NetBoxModel):
     size = models.FloatField(
         verbose_name="Size (GB)"
     )
-    path = models.CharField(
+    mount_point = models.CharField(
         max_length=255,
     )
     fs = models.ForeignKey(
@@ -291,7 +291,7 @@ class LogicalVolume(NetBoxModel):
         "vg",
         "lv_name",
         "size",
-        "path",
+        "mount_point",
         "fs",
         "description",
     ]
@@ -342,7 +342,7 @@ class MountedVolume(NetBoxModel):
         return reverse("plugins:netbox_storage:mountedvolume", kwargs={"pk": self.pk})
 
     def __str__(self):
-        return f"Filesystem Table Entry: {self.device} mounted to {self.path}"
+        return f"Filesystem Table Entry: {self.device} mounted to {self.mount_point}"
 
     class Meta:
         ordering = ("device", "mount_point", "fs_type", "options", "description")
