@@ -56,7 +56,7 @@ class LogicalVolumeIndex(SearchIndex):
     fields = (
         ('lv_name', 100),
         ('size', 100),
-        ('path', 100),
+        ('mount_point', 100),
         ('description', 100),
     )
 
@@ -65,7 +65,6 @@ class LogicalVolumeIndex(SearchIndex):
 class MountedVolumeIndex(SearchIndex):
     model = models.MountedVolume
     fields = (
-        ('size', 100),
-        ('path', 100),
+        ('mount_point', 100),
         ('description', 100),
     )
