@@ -20,7 +20,7 @@ class MountedVolumeTable(NetBoxTable):
     )
     mount_point = tables.Column(
         linkify=True,
-        verbose_name="Mount Path"
+        verbose_name="Mount point"
     )
 
     class Meta(NetBoxTable.Meta):
