@@ -1,8 +1,6 @@
-import logging
-
 from extras.plugins import PluginTemplateExtension
-from netbox_storage.models import PhysicalVolume, LogicalVolume, StorageConfigurationLinuxVolume, \
-    TemplateConfigurationLinuxVolume, Drive, Partition
+from netbox_storage.models import LogicalVolume, StorageConfigurationDrive, \
+    TemplateConfigurationDrive, Drive, Partition
 
 
 class RelatedDrives(PluginTemplateExtension):
@@ -13,7 +11,7 @@ class RelatedDrives(PluginTemplateExtension):
 
         lv = LogicalVolume.objects.all()
 
-        storage_configuration = StorageConfigurationLinuxVolume.objects.filter(virtual_machine=obj)
+        storage_configuration = StorageConfigurationDrive.objects.filter(virtual_machine=obj)
 
         platform = obj.platform
         if platform is not None:
@@ -46,7 +44,7 @@ class TemplateVolumeConfig(PluginTemplateExtension):
     def full_width_page(self):
         obj = self.context.get("object")
 
-        drives = TemplateConfigurationLinuxVolume.objects.values('drive').filter(platform=obj)
+        drives = TemplateConfigurationDrive.objects.values('drive').filter(platform=obj)
         drives_id = []
         lonely_drive = []
         for drive_id in drives:
